kendr: Kendall regression coefficient

View source: R/packdepcoeff.R

kendrR Documentation

Kendall regression coefficient

Description

The function kendr evaluates the multivariate Kendall regression coefficient. It describes how well the target variable y can be fit by a function of regressor variables which is increasing w.r.t. some regressors and decreasing w.r.t. the other regressors.

Usage

kendr(x,y,direction=NULL,out=0)

Arguments

x

data matrix of regressor variables

y

data vector of the target variable

direction

vector of length d (d is number of regressors), value 1 refers to regressors leading to increasing y whenever this regressor increases, value -1 refers to regressors leading to decreasing y whenever this regressor increases. If direction=NULL, then all coefficients are computed.

out

value 1: full output, value 0: reduced output, only coefficients that are largest in absolute value

Value

list of Kendall regression coefficients for several directions

References

Eckhard Liebscher (2019). Kendall regression coefficient. Computational Statistics and Data Analysis 157 (2021). 107140

Examples

library(MASS)
data <- gilgais
kendr(data[,1:3],data[,4],out=1)

depcoeff documentation built on Jan. 20, 2026, 5:06 p.m.

Related to kendr in depcoeff...