Learn R Programming

depcoeff (version 0.1.1)

spearr: Spearman regression coefficient

Description

The function spearr evaluates the multivariate Spearman regression coefficient. It describes how well the target variable y can be fit by a function of regressor variables which is increasing w.r.t. some regressors and decreasing w.r.t. the other regressors.

Usage

spearr(x,y,direction=NULL,out=0)

Value

list of Spearman regression coefficients for several directions

Arguments

x

data matrix of regressor variables

y

data vector of the target variable

direction

vector of length d (d is number of regressors), value 1 refers to regressors leading to increasing y whenever this regressor increases, value -1 refers to regressors leading to decreasing y whenever this regressor increases. If direction=NULL, then all coefficients are computed.

out

value 1: full output, value 0: reduced output, only coefficients that are largest in absolute value

References

Eckhard Liebscher (2021). On a multivariate version of Spearman's correlation coefficient for regression: Properties and Applications. Asian Journal of Statistical Sciences 1 (2021), No. 2, 123-150.

Examples

Run this code
library(MASS)
data <- gilgais
spearr(data[,1:3],data[,4],out=1)

Run the code above in your browser using DataLab